pub struct GitLabChart {
pub values: Option<BTreeMap<String, Value>>,
pub version: Option<String>,
}Expand description
The specification of GitLab Chart that is used to deploy the instance.
Fields
values: Option<BTreeMap<String, Value>>ChartValues is the set of Helm values that is used to render the GitLab Chart.
version: Option<String>ChartVersion is the semantic version of the GitLab Chart.