RunnerSpec

Struct RunnerSpec 

pub struct RunnerSpec {
Show 32 fields pub azure: Option<RunnerAzure>, pub build_image: Option<String>, pub ca: Option<String>, pub cache_path: Option<String>, pub cache_shared: Option<bool>, pub cache_type: Option<String>, pub clone_url: Option<String>, pub concurrent: Option<i32>, pub config: Option<String>, pub connection_max_age: Option<String>, pub deployment_spec: Option<Vec<RunnerDeploymentSpec>>, pub env: Option<String>, pub gcs: Option<RunnerGcs>, pub gitlab_url: String, pub helper_image: Option<String>, pub image_pull_policy: Option<String>, pub interval: Option<i32>, pub listen_addr: Option<String>, pub locked: Option<bool>, pub log_format: Option<String>, pub log_level: Option<String>, pub namespace: Option<String>, pub pod_spec: Option<Vec<RunnerPodSpec>>, pub protected: Option<bool>, pub run_untagged: Option<bool>, pub runner_image: Option<String>, pub s3: Option<RunnerS3>, pub sentry_dsn: Option<String>, pub serviceaccount: Option<String>, pub shutdown_timeout: Option<i32>, pub tags: Option<String>, pub token: String,
}
Specification of the desired behavior of a GitLab Runner instance

Fields

azure: Option<RunnerAzure>

options used to setup Azure blob storage as GitLab Runner Cache

build_image: Option<String>

The name of the default image to use to run build jobs, when none is specified

ca: Option<String>

Name of tls secret containing the custom certificate authority (CA) certificates

cache_path: Option<String>

Path defines the Runner Cache path

cache_shared: Option<bool>

Enable sharing of cache between Runners

cache_type: Option<String>

Type of cache used for Runner artifacts Options are: gcs, s3, azure

clone_url: Option<String>

If specified, overrides the default URL used to clone or fetch the Git ref

concurrent: Option<i32>

Option to limit the number of jobs globally that can run concurrently. The operator sets this to 10, if not specified

config: Option<String>

allow user to provide configmap name containing the user provided config.toml

connection_max_age: Option<String>

The maximum duration a TLS keepalive connection to the GitLab server should remain open before reconnecting. The default value is 15m for 15 minutes. If set to 0 or lower, the connection persists as long as possible.

deployment_spec: Option<Vec<RunnerDeploymentSpec>>

DeploymentSpec manipulates the GitLab Runner Manager’s deployment by applying [KubernetesSpecPatch]es to it. DeploymentSpec patches will be applied before [PodSpec] patches.

env: Option<String>

Accepts configmap name. Provides user mechanism to inject environment variables in the GitLab Runner pod via the key value pairs in the ConfigMap

gcs: Option<RunnerGcs>

options used to setup GCS (Google Container Storage) as GitLab Runner Cache

gitlab_url: String

The fully qualified domain name for the GitLab instance. For example, https://gitlab.example.com

helper_image: Option<String>

If specified, overrides the default GitLab Runner helper image

image_pull_policy: Option<String>

ImagePullPolicy sets the Image pull policy. One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. More info: https://kubernetes.io/docs/concepts/containers/images#updating-images

interval: Option<i32>

Option to define the number of seconds between checks for new jobs. This is set to a default of 30s by operator if not set

listen_addr: Option<String>

Option to set the metrics listen address for the runner.

locked: Option<bool>

Specify whether the runner should be locked to a specific project. Defaults to false.

log_format: Option<String>

Specifies the log format. Options are runner, text, and json. The default value is runner, which contains ANSI escape codes for coloring.

log_level: Option<String>

Option to set the log level for the runner. Valid values are “debug”, “info”, “warn”, “error”, “fatal”, “panic”

namespace: Option<String>

If specified, overrides the namespace where job pods are created

pod_spec: Option<Vec<RunnerPodSpec>>

PodSpec manipulates the GitLab Runner Manager’s pod by applying [KubernetesSpecPatch]es to it. PodSpec patches will be applied after [DeploymentSpec] patches.

protected: Option<bool>

Specify whether the runner should only run protected branches. Defaults to false.

run_untagged: Option<bool>

Specify if jobs without tags should be run. If not specified, runner will default to true if no tags were specified. In other case it will default to false.

runner_image: Option<String>

If specified, overrides the default GitLab Runner image. Default is the Runner image the operator was bundled with.

s3: Option<RunnerS3>

options used to setup S3 object store as GitLab Runner Cache

sentry_dsn: Option<String>

Enables tracking of all system level errors to Sentry. If not specified, error tracking with Sentry will be disabled.

serviceaccount: Option<String>

allow user to override service account used by GitLab Runner

shutdown_timeout: Option<i32>

Number of seconds until the forceful shutdown operation times out and exits the process. The default value is 30. If set to 0 or lower, the default value is used.

tags: Option<String>

List of comma separated tags to be applied to the runner More info: https://docs.gitlab.com/ee/ci/runners/#use-tags-to-limit-the-number-of-jobs-using-the-runner

token: String

Name of secret containing the ‘runner-registration-token’ key used to register the runner